@@ -4,17 +4,12 @@ import time
 import hmac
 import hashlib
 import base64
-try:
-    from urllib.parse import urlencode
-except ImportError:
-    from urllib import urlencode
 
 from tauros_api import exceptions
 from tauros_api.response import Response
 
-# api_url = 'https://api.staging.tauros.io'
-api_url = 'http://192.168.139.130:8000'
-api_staging_url = 'https://api.tauros.io'
+api_url = 'https://api.tauros.io'
+api_staging_url = 'https://api.staging.tauros.io'
 
 
 class TaurosAPI():
@@ -93,9 +88,7 @@ class TaurosAPI():
         if not isinstance(data, dict):
             return None
         try:
-            request_data = urlencode(data)
-
-            print(request_data)
+            request_data = json.dumps(data, separators=(',', ':'))
 
             message = str(nonce) + method.upper() + path + request_data
 
