@@ -1,4 +1,4 @@
-from tests.test_request_post import RequestPost
+from tests.test_request_post import *
 
 if __name__ == '__main__':
     unittest.main()
